# malmstin

[![Release](https://img.shields.io/github/v/release/loucerac/malmstin)](https://img.shields.io/github/v/release/loucerac/malmstin)
[![Build status](https://img.shields.io/github/actions/workflow/status/loucerac/malmstin/main.yml?branch=main)](https://github.com/loucerac/malmstin/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/loucerac/malmstin/branch/main/graph/badge.svg)](https://codecov.io/gh/loucerac/malmstin)
[![Commit activity](https://img.shields.io/github/commit-activity/m/loucerac/malmstin)](https://img.shields.io/github/commit-activity/m/loucerac/malmstin)
[![License](https://img.shields.io/github/license/loucerac/malmstin)](https://img.shields.io/github/license/loucerac/malmstin)

Unveiling the Druggable Landscape: A Multimodal Approach (MALMSTIN)

- **Github repository**: <https://github.com/loucerac/malmstin/>
- **Documentation** <https://loucerac.github.io/malmstin/>

## Getting started with the project

Install the environment and the pre-commit hooks with

```bash
make install
```

## Develop
